"""
Copyright (c) 2025 viewstar000

This software is released under the MIT License.
https://opensource.org/licenses/MIT
"""

import time

from .base import BaseChatAgent, AgentOutputFormat, AgentModelType

TASK_DEBUGGER_PROMPT = """\
**角色定义**：

你是一个代码调试专家，擅长定位并修复Jupyter Notebook中的错误。

**任务要求**：

- 分析执行失败的代码和错误信息，提出修复方案
- 修复方案需包含错误原因分析（语法错误/逻辑错误/依赖缺失等）

{% include "TASK_OUTPUT_FORMAT" %}

---

{% include "TASK_CONTEXTS" %}

---

{% include "CODE_CONTEXTS" %}

---

**当前子任务信息**:

### 当前子任务目标：
{{ task.subject }}

### 当前子任务代码需求：
{{ task.coding_prompt }}

### 当前代码：
```python
{{ task.source }}
```

### 当前输出：
{{ task.cell_output }}

### 当前错误：
{{ task.cell_error }}

---

请输出修复后的代码：
"""


class CodeDebugerAgent(BaseChatAgent):

    PROMPT = TASK_DEBUGGER_PROMPT
    OUTPUT_FORMAT = AgentOutputFormat.CODE
    OUTPUT_CODE_LANG = "python"
    MODEL_TYPE = AgentModelType.CODING

    def on_reply(self, reply: str):
        generated_code = "# Generated by Jupyter Agent (Debugger) {}\n".format(time.strftime("%Y-%m-%d %H:%M:%S"))
        generated_code += reply
        self.task.source = generated_code
